@@ -20,7 +20,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <gtk/gtk.h>
 #include <misc/e-canvas-background.h>
@@ -30,23 +32,38 @@
 #include "e-util/e-util.h"
 #include "e-minicard-view-widget.h"
 
-static void e_minicard_view_widget_init		 (EMinicardViewWidget		 *widget);
-static void e_minicard_view_widget_class_init	 (EMinicardViewWidgetClass	 *class);
-static void e_minicard_view_widget_set_property  (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
-static void e_minicard_view_widget_get_property  (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
-static void e_minicard_view_widget_dispose       (GObject *object);
-static void e_minicard_view_widget_reflow        (ECanvas *canvas);
-static void e_minicard_view_widget_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
-static void e_minicard_view_widget_style_set     (GtkWidget *widget, GtkStyle *previous_style);
-static void e_minicard_view_widget_realize       (GtkWidget *widget);
-static gboolean e_minicard_view_widget_real_focus_in_event (GtkWidget *widget, GdkEventFocus *event);
+static void	e_minicard_view_widget_init	(EMinicardViewWidget *widget);
+static void	e_minicard_view_widget_class_init
+						 (EMinicardViewWidgetClass *class);
+static void	e_minicard_view_widget_set_property
+						(GObject *object,
+						 guint property_id,
+						 const GValue *value,
+						 GParamSpec *pspec);
+static void	e_minicard_view_widget_get_property
+						(GObject *object,
+						 guint property_id,
+						 GValue *value,
+						 GParamSpec *pspec);
+static void	e_minicard_view_widget_dispose	(GObject *object);
+static void	e_minicard_view_widget_reflow	(ECanvas *canvas);
+static void	e_minicard_view_widget_size_allocate
+						(GtkWidget *widget,
+						 GtkAllocation *allocation);
+static void	e_minicard_view_widget_style_set
+						(GtkWidget *widget,
+						 GtkStyle *previous_style);
+static void	e_minicard_view_widget_realize	(GtkWidget *widget);
+static gboolean	e_minicard_view_widget_real_focus_in_event
+						(GtkWidget *widget,
+						 GdkEventFocus *event);
 
 static gpointer parent_class;
 
 /* The arguments we take */
 enum {
 	PROP_0,
-	PROP_BOOK,
+	PROP_CLIENT,
 	PROP_QUERY,
 	PROP_EDITABLE,
 	PROP_COLUMN_WIDTH
@@ -81,7 +98,8 @@ e_minicard_view_widget_get_type (void)
 			(GInstanceInitFunc) e_minicard_view_widget_init,
 		};
 
-		type = g_type_register_static (e_canvas_get_type (), "EMinicardViewWidget", &info, 0);
+		type = g_type_register_static (
+			E_TYPE_CANVAS, "EMinicardViewWidget", &info, 0);
 	}
 
 	return type;
@@ -114,11 +132,11 @@ e_minicard_view_widget_class_init (EMinicardViewWidgetClass *class)
 	class->column_width_changed = NULL;
 	class->right_click = NULL;
 
-	g_object_class_install_property (object_class, PROP_BOOK,
-					 g_param_spec_object ("book",
-							      "Book",
+	g_object_class_install_property (object_class, PROP_CLIENT,
+					 g_param_spec_object ("client",
+							      "EBookClient",
 							      NULL,
-							      E_TYPE_BOOK,
+							      E_TYPE_BOOK_CLIENT,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_QUERY,
@@ -193,7 +211,7 @@ e_minicard_view_widget_init (EMinicardViewWidget *view)
 {
 	view->emv = NULL;
 
-	view->book = NULL;
+	view->book_client = NULL;
 	view->query = NULL;
 	view->editable = FALSE;
 	view->column_width = 225;
@@ -202,37 +220,38 @@ e_minicard_view_widget_init (EMinicardViewWidget *view)
 GtkWidget *
 e_minicard_view_widget_new (EAddressbookReflowAdapter *adapter)
 {
-	EMinicardViewWidget *widget = E_MINICARD_VIEW_WIDGET (g_object_new (e_minicard_view_widget_get_type (), NULL));
+	EMinicardViewWidget *widget;
 
-	widget->adapter = adapter;
-	g_object_ref (widget->adapter);
+	widget = g_object_new (E_TYPE_MINICARD_VIEW_WIDGET, NULL);
+
+	widget->adapter = g_object_ref (adapter);
 
 	return GTK_WIDGET (widget);
 }
 
 static void
 e_minicard_view_widget_set_property (GObject *object,
-				     guint prop_id,
-				     const GValue *value,
-				     GParamSpec *pspec)
+                                     guint property_id,
+                                     const GValue *value,
+                                     GParamSpec *pspec)
 {
 	EMinicardViewWidget *emvw;
 
 	emvw = E_MINICARD_VIEW_WIDGET (object);
 
-	switch (prop_id) {
-	case PROP_BOOK:
-		if (emvw->book)
-			g_object_unref (emvw->book);
+	switch (property_id) {
+	case PROP_CLIENT:
+		if (emvw->book_client)
+			g_object_unref (emvw->book_client);
 		if (g_value_get_object (value)) {
-			emvw->book = E_BOOK (g_value_get_object (value));
-			if (emvw->book)
-				g_object_ref (emvw->book);
+			emvw->book_client = E_BOOK_CLIENT (g_value_get_object (value));
+			if (emvw->book_client)
+				g_object_ref (emvw->book_client);
 		} else
-			emvw->book = NULL;
+			emvw->book_client = NULL;
 		if (emvw->emv)
 			g_object_set (emvw->emv,
-				     "book", emvw->book,
+				     "client", emvw->book_client,
 				       NULL);
 		break;
 	case PROP_QUERY:
@@ -258,24 +277,24 @@ e_minicard_view_widget_set_property (GObject *object,
 		}
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
 	}
 }
 
 static void
 e_minicard_view_widget_get_property (GObject *object,
-				     guint prop_id,
-				     GValue *value,
-				     GParamSpec *pspec)
+                                     guint property_id,
+                                     GValue *value,
+                                     GParamSpec *pspec)
 {
 	EMinicardViewWidget *emvw;
 
 	emvw = E_MINICARD_VIEW_WIDGET (object);
 
-	switch (prop_id) {
-	case PROP_BOOK:
-		g_value_set_object (value, emvw->book);
+	switch (property_id) {
+	case PROP_CLIENT:
+		g_value_set_object (value, emvw->book_client);
 		break;
 	case PROP_QUERY:
 		g_value_set_string (value, emvw->query);
@@ -287,7 +306,7 @@ e_minicard_view_widget_get_property (GObject *object,
 		g_value_set_double (value, emvw->column_width);
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
 	}
 }
@@ -297,9 +316,9 @@ e_minicard_view_widget_dispose (GObject *object)
 {
 	EMinicardViewWidget *view = E_MINICARD_VIEW_WIDGET (object);
 
-	if (view->book) {
-		g_object_unref (view->book);
-		view->book = NULL;
+	if (view->book_client) {
+		g_object_unref (view->book_client);
+		view->book_client = NULL;
 	}
 	if (view->query) {
 		g_free (view->query);
@@ -316,49 +335,57 @@ e_minicard_view_widget_dispose (GObject *object)
 }
 
 static void
-selection_change (ESelectionModel *esm, EMinicardViewWidget *widget)
+selection_change (ESelectionModel *esm,
+                  EMinicardViewWidget *widget)
 {
-	g_signal_emit (widget,
-		       signals[SELECTION_CHANGE], 0);
+	g_signal_emit (widget, signals[SELECTION_CHANGE], 0);
 }
 
 static void
-selection_row_change (ESelectionModel *esm, gint row, EMinicardViewWidget *widget)
+selection_row_change (ESelectionModel *esm,
+                      gint row,
+                      EMinicardViewWidget *widget)
 {
 	selection_change (esm, widget);
 }
 
 static void
-column_width_changed (ESelectionModel *esm, double width, EMinicardViewWidget *widget)
+column_width_changed (ESelectionModel *esm,
+                      gdouble width,
+                      EMinicardViewWidget *widget)
 {
-	g_signal_emit (widget,
-		       signals[COLUMN_WIDTH_CHANGED], 0, width);
+	g_signal_emit (widget, signals[COLUMN_WIDTH_CHANGED], 0, width);
 }
 
 static void
-create_contact (EMinicardView *view, EMinicardViewWidget *widget)
+create_contact (EMinicardView *view,
+                EMinicardViewWidget *widget)
 {
 	g_signal_emit (widget, signals[CREATE_CONTACT], 0);
 }
 
 static void
-create_contact_list (EMinicardView *view, EMinicardViewWidget *widget)
+create_contact_list (EMinicardView *view,
+                     EMinicardViewWidget *widget)
 {
 	g_signal_emit (widget, signals[CREATE_CONTACT_LIST], 0);
 }
 
 static guint
-right_click (EMinicardView *view, GdkEvent *event, EMinicardViewWidget *widget)
+right_click (EMinicardView *view,
+             GdkEvent *event,
+             EMinicardViewWidget *widget)
 {
 	guint ret_val;
-	g_signal_emit (widget,
-		       signals[RIGHT_CLICK], 0,
-		       event, &ret_val);
+
+	g_signal_emit (widget, signals[RIGHT_CLICK], 0, event, &ret_val);
+
 	return ret_val;
 }
 
 static void
-e_minicard_view_widget_style_set (GtkWidget *widget, GtkStyle *previous_style)
+e_minicard_view_widget_style_set (GtkWidget *widget,
+                                  GtkStyle *previous_style)
 {
 	EMinicardViewWidget *view = E_MINICARD_VIEW_WIDGET (widget);
 	GtkStyle *style;
@@ -380,13 +407,14 @@ e_minicard_view_widget_realize (GtkWidget *widget)
 	EMinicardViewWidget *view = E_MINICARD_VIEW_WIDGET (widget);
 	GtkStyle *style = gtk_widget_get_style (widget);
 
-	view->background = gnome_canvas_item_new (gnome_canvas_root ( GNOME_CANVAS (view) ),
-						 e_canvas_background_get_type (),
-						 "fill_color_gdk", &style->base[GTK_STATE_NORMAL],
-						 NULL );
+	view->background = gnome_canvas_item_new (
+		gnome_canvas_root (GNOME_CANVAS (view)),
+		e_canvas_background_get_type (),
+		"fill_color_gdk", &style->base[GTK_STATE_NORMAL],
+		NULL );
 
 	view->emv = gnome_canvas_item_new (
-		gnome_canvas_root ( GNOME_CANVAS (view) ),
+		gnome_canvas_root (GNOME_CANVAS (view)),
 		e_minicard_view_get_type (),
 		"height", (double) 100,
 		"minimum_width", (double) 100,
@@ -394,31 +422,34 @@ e_minicard_view_widget_realize (GtkWidget *widget)
 		"column_width", view->column_width,
 		NULL );
 
-	g_signal_connect (E_REFLOW (view->emv)->selection,
-			  "selection_changed",
-			  G_CALLBACK (selection_change), view);
-	g_signal_connect (E_REFLOW (view->emv)->selection,
-			  "selection_row_changed",
-			  G_CALLBACK (selection_row_change), view);
-	g_signal_connect (view->emv,
-			  "column_width_changed",
-			  G_CALLBACK (column_width_changed), view);
-	g_signal_connect (view->emv,
-			  "create-contact",
-			  G_CALLBACK (create_contact), view);
-	g_signal_connect (view->emv,
-			  "create-contact-list",
-			  G_CALLBACK (create_contact_list), view);
-	g_signal_connect (view->emv,
-			  "right_click",
-			  G_CALLBACK (right_click), view);
+	g_signal_connect (
+		E_REFLOW (view->emv)->selection,
+		"selection_changed",
+		G_CALLBACK (selection_change), view);
+	g_signal_connect (
+		E_REFLOW (view->emv)->selection,
+		"selection_row_changed",
+		G_CALLBACK (selection_row_change), view);
+	g_signal_connect (
+		view->emv, "column_width_changed",
+		G_CALLBACK (column_width_changed), view);
+	g_signal_connect (
+		view->emv, "create-contact",
+		G_CALLBACK (create_contact), view);
+	g_signal_connect (
+		view->emv, "create-contact-list",
+		G_CALLBACK (create_contact_list), view);
+	g_signal_connect (
+		view->emv, "right_click",
+		G_CALLBACK (right_click), view);
 
 	if (GTK_WIDGET_CLASS (parent_class)->realize)
 		GTK_WIDGET_CLASS (parent_class)->realize (widget);
 }
 
 static void
-e_minicard_view_widget_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
+e_minicard_view_widget_size_allocate (GtkWidget *widget,
+                                      GtkAllocation *allocation)
 {
 	if (GTK_WIDGET_CLASS (parent_class)->size_allocate)
 		GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
@@ -427,17 +458,17 @@ e_minicard_view_widget_size_allocate (GtkWidget *widget, GtkAllocation *allocati
 		gdouble width;
 		EMinicardViewWidget *view = E_MINICARD_VIEW_WIDGET (widget);
 
-		gnome_canvas_item_set ( view->emv,
-				       "height", (double) allocation->height,
-				       NULL );
-		gnome_canvas_item_set ( view->emv,
-				       "minimum_width", (double) allocation->width,
-				       NULL );
-		g_object_get (view->emv,
-			     "width", &width,
-			     NULL);
+		gnome_canvas_item_set (
+			view->emv, "height",
+			(gdouble) allocation->height, NULL);
+		gnome_canvas_item_set (
+			view->emv, "minimum_width",
+			(gdouble) allocation->width, NULL);
+		g_object_get (view->emv, "width", &width, NULL);
 		width = MAX (width, allocation->width);
-		gnome_canvas_set_scroll_region (GNOME_CANVAS (view), 0, 0, width - 1, allocation->height - 1);
+		gnome_canvas_set_scroll_region (
+			GNOME_CANVAS (view), 0, 0,
+			width - 1, allocation->height - 1);
 	}
 }
 
@@ -470,7 +501,7 @@ e_minicard_view_widget_get_selection_model (EMinicardViewWidget *view)
 }
 
 EMinicardView *
-e_minicard_view_widget_get_view             (EMinicardViewWidget       *view)
+e_minicard_view_widget_get_view (EMinicardViewWidget *view)
 {
 	if (view->emv)
 		return E_MINICARD_VIEW (view->emv);
@@ -479,7 +510,8 @@ e_minicard_view_widget_get_view             (EMinicardViewWidget       *view)
 }
 
 static gboolean
-e_minicard_view_widget_real_focus_in_event (GtkWidget *widget, GdkEventFocus *event)
+e_minicard_view_widget_real_focus_in_event (GtkWidget *widget,
+                                            GdkEventFocus *event)
 {
 	GnomeCanvas *canvas;
 	EMinicardViewWidget *view;
@@ -501,6 +533,5 @@ e_minicard_view_widget_real_focus_in_event (GtkWidget *widget, GdkEventFocus *ev
 		return GTK_WIDGET_CLASS (parent_class)->focus_in_event (widget, event);
 
 	return FALSE;
-
 }
 
