@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -20,17 +20,19 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
-#include <libebook/e-book.h>
+#include <libebook/e-book-client.h>
+#include <libebook/e-book-query.h>
 #include <libebook/e-contact.h>
 
 #include "evolution-addressbook-export.h"
@@ -146,7 +148,7 @@ struct _EContactCSVFieldData
 {
 	gint csv_field;
 	gint contact_field;
-	gchar *csv_name;
+	const gchar *csv_name;
 	EContactCSVDataType data_type;
 };
 
@@ -166,7 +168,7 @@ static EContactCSVFieldData csv_field_data[] = {
 	{E_CONTACT_CSV_PHONE_HOME,	E_CONTACT_PHONE_HOME,	   "", DT_STRING},
 	{E_CONTACT_CSV_ORG,		E_CONTACT_ORG,		   "", DT_STRING},
 	/*E_CONTACT_CSV_ADDRESS_BUSINESS, */
-	{E_CONTACT_CSV_ADDRESS_BUSINESS_STREET,	  NOMAP, "Business Address", 	      DT_STRING},
+	{E_CONTACT_CSV_ADDRESS_BUSINESS_STREET,	  NOMAP, "Business Address",	      DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_BUSINESS_EXT,	  NOMAP, "Business Address2",         DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_BUSINESS_CITY,	  NOMAP, "Business Address City",     DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_BUSINESS_REGION,	  NOMAP, "Business Address State",    DT_STRING},
@@ -179,7 +181,7 @@ static EContactCSVFieldData csv_field_data[] = {
 	{E_CONTACT_CSV_ADDRESS_HOME_REGION,   NOMAP, "Home Address State",    DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_HOME_POSTCODE, NOMAP, "Home Address PostCode", DT_STRING},
 	{E_CONTACT_CSV_ADDRESS_HOME_COUNTRY,  NOMAP, "Home Address Country",  DT_STRING},
-	{E_CONTACT_CSV_PHONE_MOBILE, 	      E_CONTACT_PHONE_MOBILE,       "", DT_STRING},
+	{E_CONTACT_CSV_PHONE_MOBILE,	      E_CONTACT_PHONE_MOBILE,       "", DT_STRING},
 	{E_CONTACT_CSV_PHONE_CAR,	      E_CONTACT_PHONE_CAR,          "", DT_STRING},
 	{E_CONTACT_CSV_PHONE_BUSINESS_FAX,    E_CONTACT_PHONE_BUSINESS_FAX, "", DT_STRING},
 	{E_CONTACT_CSV_PHONE_HOME_FAX,        E_CONTACT_PHONE_HOME_FAX,     "", DT_STRING},
@@ -242,11 +244,9 @@ gchar *e_contact_get_csv (EContact * contact, GSList * csv_all_fields);
 gchar *delivery_address_get_sub_field (const EContactAddress * delivery_address, DeliveryAddressField sub_field);
 gchar *check_null_pointer (gchar * orig);
 gchar *escape_string (gchar * orig);
-int output_n_cards_file (FILE * outputfile, GList *contacts, int size, int begin_no, CARD_FORMAT format);
+gint output_n_cards_file (FILE * outputfile, GSList *contacts, gint size, gint begin_no, CARD_FORMAT format);
 static void fork_to_background (void);
 void set_pre_defined_field (GSList ** pre_defined_fields);
-guint action_list_cards_init (ActionContext * p_actctx);
-
 
 /* function declarations*/
 gint
@@ -280,9 +280,9 @@ e_contact_csv_get_name (EContactFieldCSV csv_field)
 	return quoted_name;
 }
 
-
 gchar *
-e_contact_csv_get (EContact * contact, EContactFieldCSV csv_field)
+e_contact_csv_get (EContact *contact,
+                   EContactFieldCSV csv_field)
 {
 	gint contact_field;
 	gchar *field_value;
@@ -399,9 +399,8 @@ e_contact_csv_get (EContact * contact, EContactFieldCSV csv_field)
 	return quoted_field_value;
 }
 
-
 gchar *
-e_contact_csv_get_header_line (GSList * csv_all_fields)
+e_contact_csv_get_header_line (GSList *csv_all_fields)
 {
 
 	guint field_number;
@@ -430,9 +429,9 @@ e_contact_csv_get_header_line (GSList * csv_all_fields)
 
 }
 
-
 gchar *
-e_contact_to_csv (EContact * contact, GSList * csv_all_fields)
+e_contact_to_csv (EContact *contact,
+                  GSList *csv_all_fields)
 {
 	guint field_number;
 	gint csv_field;
@@ -460,9 +459,9 @@ e_contact_to_csv (EContact * contact, GSList * csv_all_fields)
 
 }
 
-
 gchar *
-e_contact_get_csv (EContact * contact, GSList * csv_all_fields)
+e_contact_get_csv (EContact *contact,
+                   GSList *csv_all_fields)
 {
 	gchar *aline;
 
@@ -470,9 +469,8 @@ e_contact_get_csv (EContact * contact, GSList * csv_all_fields)
 	return aline;
 }
 
-
 gchar *
-check_null_pointer (gchar * orig)
+check_null_pointer (gchar *orig)
 {
 	gchar *result;
 	if (orig == NULL)
@@ -483,7 +481,8 @@ check_null_pointer (gchar * orig)
 }
 
 gchar *
-delivery_address_get_sub_field (const EContactAddress * address, DeliveryAddressField sub_field)
+delivery_address_get_sub_field (const EContactAddress *address,
+                                DeliveryAddressField sub_field)
 {
 	gchar *sub_field_value;
 	gchar *str_temp, *str_temp_a;
@@ -567,13 +566,17 @@ escape_string (gchar *orig)
 	return dest;
 }
 
-int
-output_n_cards_file (FILE * outputfile, GList *contacts, int size, int begin_no, CARD_FORMAT format)
+gint
+output_n_cards_file (FILE *outputfile,
+                     GSList *contacts,
+                     gint size,
+                     gint begin_no,
+                     CARD_FORMAT format)
 {
-	int i;
+	gint i;
 	if (format == CARD_FORMAT_VCARD) {
 		for (i = begin_no; i < size + begin_no; i++) {
-			EContact *contact = g_list_nth_data (contacts, i);
+			EContact *contact = g_slist_nth_data (contacts, i);
 			gchar *vcard = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 			fprintf (outputfile, "%s\n", vcard);
 			g_free (vcard);
@@ -589,7 +592,7 @@ output_n_cards_file (FILE * outputfile, GList *contacts, int size, int begin_no,
 		g_free (csv_fields_name);
 
 		for (i = begin_no; i < size + begin_no; i++) {
-			EContact *contact = g_list_nth_data (contacts, i);
+			EContact *contact = g_slist_nth_data (contacts, i);
 			gchar *csv = e_contact_get_csv (contact, pre_defined_fields);
 			fprintf (outputfile, "%s\n", csv);
 			g_free (csv);
@@ -621,21 +624,19 @@ fork_to_background (void)
 #endif
 }
 
-
-
-
 static void
-action_list_cards (GList *contacts, ActionContext * p_actctx)
+action_list_cards (GSList *contacts,
+                   ActionContext *p_actctx)
 {
 	FILE *outputfile;
 	long length;
-	int IsFirstOne;
-	int series_no;
+	gint IsFirstOne;
+	gint series_no;
 	gchar *file_series_name;
 	CARD_FORMAT format;
-	int size;
+	gint size;
 
-	length = g_list_length (contacts);
+	length = g_slist_length (contacts);
 
 	if (length <= 0) {
 		g_warning ("Couldn't load addressbook correctly!!!! %s####", p_actctx->action_list_cards.addressbook_folder_uri ?
@@ -643,7 +644,6 @@ action_list_cards (GList *contacts, ActionContext * p_actctx)
 		exit (-1);
 	}
 
-
 	if (p_actctx->action_list_cards.async_mode == FALSE) {	/* normal mode */
 
 		if (p_actctx->action_list_cards.output_file == NULL) {
@@ -668,7 +668,6 @@ action_list_cards (GList *contacts, ActionContext * p_actctx)
 		}
 	}
 
-
 	/*async mode */
 	else {
 
@@ -691,7 +690,6 @@ action_list_cards (GList *contacts, ActionContext * p_actctx)
 				exit (-1);
 			}
 
-
 			if (p_actctx->action_list_cards.IsVCard == TRUE)
 				format = CARD_FORMAT_VCARD;
 			else
@@ -707,7 +705,6 @@ action_list_cards (GList *contacts, ActionContext * p_actctx)
 				IsFirstOne = FALSE;
 			}
 
-
 		}
 		while (series_no * size < length);
 		g_free (file_series_name);
@@ -723,7 +720,7 @@ action_list_cards (GList *contacts, ActionContext * p_actctx)
 }
 
 void
-set_pre_defined_field (GSList ** pre_defined_fields)
+set_pre_defined_field (GSList **pre_defined_fields)
 {
 	*pre_defined_fields = NULL;
 	*pre_defined_fields = g_slist_append (*pre_defined_fields, GINT_TO_POINTER (E_CONTACT_CSV_GIVEN_NAME));
@@ -772,33 +769,49 @@ set_pre_defined_field (GSList ** pre_defined_fields)
 }
 
 guint
-action_list_cards_init (ActionContext * p_actctx)
+action_list_cards_init (ActionContext *p_actctx)
 {
-	EBook *book;
+	EBookClient *book_client;
 	EBookQuery *query;
-	GList *contacts;
+	gchar *query_str;
+	GSList *contacts;
+	GError *error = NULL;
 
 	if (p_actctx->action_list_cards.addressbook_folder_uri != NULL) {
-		book = e_book_new_from_uri (p_actctx->action_list_cards.addressbook_folder_uri, NULL);
+		book_client = e_book_client_new_from_uri (p_actctx->action_list_cards.addressbook_folder_uri, &error);
 	} else {
-		book = e_book_new_default_addressbook (NULL);
+		book_client = e_book_client_new_default (&error);
 	}
 
-	if (!book
-	    || !e_book_open (book, TRUE, NULL)) {
-		g_warning ("Couldn't load addressbook %s", p_actctx->action_list_cards.addressbook_folder_uri ?
-					p_actctx->action_list_cards.addressbook_folder_uri : "NULL");
+	if (!book_client
+	    || !e_client_open_sync (E_CLIENT (book_client), TRUE, NULL, &error)) {
+		g_warning ("Couldn't load addressbook %s: %s", p_actctx->action_list_cards.addressbook_folder_uri ?
+				p_actctx->action_list_cards.addressbook_folder_uri : "'default'",
+				error ? error->message : "Unknown error");
+		if (error)
+			g_error_free (error);
+		if (book_client)
+			g_object_unref (book_client);
 		exit (-1);
 	}
 
 	query = e_book_query_any_field_contains ("");
-	e_book_get_contacts (book, query, &contacts, NULL);
+	query_str = e_book_query_to_string (query);
 	e_book_query_unref (query);
 
+	if (!e_book_client_get_contacts_sync (book_client, query_str, &contacts, NULL, &error))
+		contacts = NULL;
+
 	action_list_cards (contacts, p_actctx);
 
-	g_list_foreach (contacts, (GFunc)g_object_unref, NULL);
-	g_list_free (contacts);
+	g_slist_foreach (contacts, (GFunc) g_object_unref, NULL);
+	g_slist_free (contacts);
+	g_object_unref (book_client);
 
-	return SUCCESS;
+	if (error) {
+		g_warning ("Failed to get contacts: %s", error->message);
+		g_error_free (error);
+	}
+
+	return error ? FAILED : SUCCESS;
 }
