@@ -39,11 +39,6 @@
 
 #include <gtk/gtk.h>
 #include <stdarg.h>
-#include <libart_lgpl/art_misc.h>
-#include <libart_lgpl/art_rect.h>
-#include <libart_lgpl/art_svp.h>
-#include <libart_lgpl/art_uta.h>
-#include <libart_lgpl/art_affine.h>
 
 G_BEGIN_DECLS
 
@@ -89,13 +84,11 @@ typedef struct _GnomeCanvasGroupClass GnomeCanvasGroupClass;
 typedef enum {
 	GNOME_CANVAS_ITEM_REALIZED      = 1 << 0,
 	GNOME_CANVAS_ITEM_MAPPED        = 1 << 1,
-	GNOME_CANVAS_ITEM_ALWAYS_REDRAW = 1 << 2,
-	GNOME_CANVAS_ITEM_VISIBLE       = 1 << 3,
-	GNOME_CANVAS_ITEM_NEED_UPDATE	= 1 << 4,
-	GNOME_CANVAS_ITEM_NEED_AFFINE	= 1 << 5,
-	GNOME_CANVAS_ITEM_NEED_CLIP	= 1 << 6,
-	GNOME_CANVAS_ITEM_NEED_VIS	= 1 << 7,
-	GNOME_CANVAS_ITEM_AFFINE_FULL	= 1 << 8
+	GNOME_CANVAS_ITEM_VISIBLE       = 1 << 2,
+	GNOME_CANVAS_ITEM_NEED_UPDATE	= 1 << 3,
+	GNOME_CANVAS_ITEM_NEED_AFFINE	= 1 << 4,
+	GNOME_CANVAS_ITEM_NEED_CLIP	= 1 << 5,
+	GNOME_CANVAS_ITEM_NEED_VIS	= 1 << 6
 } GnomeCanvasItemFlags;
 
 /* Update flags for items */
@@ -107,29 +100,6 @@ enum {
 	GNOME_CANVAS_UPDATE_IS_VISIBLE = 1 << 4		/* Deprecated.  FIXME: remove this */
 };
 
-/* Data for rendering in antialiased mode */
-typedef struct {
-	/* 24-bit RGB buffer for rendering */
-	guchar *buf;
-
-	/* Rectangle describing the rendering area */
-	ArtIRect rect;
-
-	/* Rowstride for the buffer */
-	gint buf_rowstride;
-
-	/* Background color, given as 0xrrggbb */
-	guint32 bg_color;
-
-	/* Invariant: at least one of the following flags is true. */
-
-	/* Set when the render rectangle area is the solid color bg_color */
-	guint is_bg : 1;
-
-	/* Set when the render rectangle area is represented by the buf */
-	guint is_buf : 1;
-} GnomeCanvasBuf;
-
 #define GNOME_TYPE_CANVAS_ITEM            (gnome_canvas_item_get_type ())
 #define GNOME_CANVAS_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_CANVAS_ITEM, GnomeCanvasItem))
 #define GNOME_CANVAS_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_TYPE_CANVAS_ITEM, GnomeCanvasItemClass))
@@ -138,7 +108,7 @@ typedef struct {
 #define GNOME_CANVAS_ITEM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_CANVAS_ITEM, GnomeCanvasItemClass))
 
 struct _GnomeCanvasItem {
-	GtkObject object;
+	GObject object;
 
 	/* Parent canvas for this item */
 	GnomeCanvas *canvas;
@@ -146,23 +116,19 @@ struct _GnomeCanvasItem {
 	/* Parent canvas group for this item (a GnomeCanvasGroup) */
 	GnomeCanvasItem *parent;
 
-	/* If NULL, assumed to be the identity tranform.  If flags does not have
-	 * AFFINE_FULL, then a two-element array containing a translation.  If
-	 * flags contains AFFINE_FULL, a six-element array containing an affine
-	 * transformation.
-	 */
-	gdouble *xform;
+	/* The transformation for this item */
+	cairo_matrix_t matrix;
 
 	/* Bounding box for this item (in canvas coordinates) */
 	gdouble x1, y1, x2, y2;
 
-	/* XXX GtkObject flags are sealed now, so we have to provide
+	/* XXX GObject flags are sealed now, so we have to provide
 	 *     our own.  This breaks ABI compatibility with upstream. */
 	GnomeCanvasItemFlags flags;
 };
 
 struct _GnomeCanvasItemClass {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 
 	/* Tell the item to update itself.  The flags are from the update flags
 	 * defined above.  The item should update its internal state from its
@@ -170,7 +136,7 @@ struct _GnomeCanvasItemClass {
 	 * affine, if used, is a pointer to a 6-element array of doubles.  The
 	 * update method also recomputes the bounding box of the item.
 	 */
-	void (* update) (GnomeCanvasItem *item, gdouble *affine, ArtSVP *clip_path, gint flags);
+	void (* update) (GnomeCanvasItem *item, const cairo_matrix_t *i2c, gint flags);
 
 	/* Realize an item -- create GCs, etc. */
 	void (* realize) (GnomeCanvasItem *item);
@@ -184,32 +150,23 @@ struct _GnomeCanvasItemClass {
 	/* Unmap an item */
 	void (* unmap) (GnomeCanvasItem *item);
 
-	/* Return the microtile coverage of the item */
-	ArtUta *(* coverage) (GnomeCanvasItem *item);
+	/* Dispose item; called inside GObject's dispose of the base class */
+	void (* dispose) (GnomeCanvasItem *item);
 
 	/* Draw an item of this type.  (x, y) are the upper-left canvas pixel
 	 * coordinates of the drawable, a temporary pixmap, where things get
 	 * drawn.  (width, height) are the dimensions of the drawable.
 	 */
-	void (* draw) (GnomeCanvasItem *item, GdkDrawable *drawable,
+	void (* draw) (GnomeCanvasItem *item, cairo_t *cr,
 		       gint x, gint y, gint width, gint height);
 
-	/* Render the item over the buffer given.  The buf data structure
-	 * contains both a pointer to a packed 24-bit RGB array, and the
-	 * coordinates.  This method is only used for antialiased canvases.
-	 *
-	 * TODO: figure out where clip paths fit into the rendering framework.
+        /* Returns the canvas item which is at the given location. This is the
+         * item itself in the case of the object being an actual leaf item, or
+         * a child in case of the object being a canvas group.  (cx, cy) are
+         * the canvas pixel coordinates that correspond to the item-relative
+         * coordinates (x, y).
 	 */
-	void (* render) (GnomeCanvasItem *item, GnomeCanvasBuf *buf);
-
-	/* Calculate the distance from an item to the specified point.  It also
-         * returns a canvas item which is the item itself in the case of the
-         * object being an actual leaf item, or a child in case of the object
-         * being a canvas group.  (cx, cy) are the canvas pixel coordinates that
-         * correspond to the item-relative coordinates (x, y).
-	 */
-	gdouble (* point) (GnomeCanvasItem *item, gdouble x, gdouble y, gint cx, gint cy,
-			  GnomeCanvasItem **actual_item);
+	GnomeCanvasItem * (* point) (GnomeCanvasItem *item, gdouble x, gdouble y, gint cx, gint cy);
 
 	/* Fetch the item's bounding box (need not be exactly tight).  This
 	 * should be in item-relative coordinates.
@@ -222,7 +179,7 @@ struct _GnomeCanvasItemClass {
 	gboolean (* event)                (GnomeCanvasItem *item, GdkEvent *event);
 
 	/* Reserved for future expansion */
-	gpointer spare_vmethods [4];
+	gpointer spare_vmethods[4];
 };
 
 GType gnome_canvas_item_get_type (void) G_GNUC_CONST;
@@ -251,10 +208,10 @@ void gnome_canvas_item_set_valist (GnomeCanvasItem *item,
 void gnome_canvas_item_move (GnomeCanvasItem *item, gdouble dx, gdouble dy);
 
 /* Apply a relative affine transformation to the item. */
-void gnome_canvas_item_affine_relative (GnomeCanvasItem *item, const gdouble affine[6]);
+void gnome_canvas_item_transform (GnomeCanvasItem *item, const cairo_matrix_t *matrix);
 
 /* Apply an absolute affine transformation to the item. */
-void gnome_canvas_item_affine_absolute (GnomeCanvasItem *item, const gdouble affine[6]);
+void gnome_canvas_item_set_matrix (GnomeCanvasItem *item, const cairo_matrix_t *matrix);
 
 /* Raise an item in the z-order of its parent group by the specified number of
  * positions.
@@ -304,12 +261,13 @@ void gnome_canvas_item_i2w (GnomeCanvasItem *item, gdouble *x, gdouble *y);
 /* Gets the affine transform that converts from item-relative coordinates to
  * world coordinates.
  */
-void gnome_canvas_item_i2w_affine (GnomeCanvasItem *item, gdouble affine[6]);
+void gnome_canvas_item_i2w_matrix (GnomeCanvasItem *item, cairo_matrix_t *matrix);
+void gnome_canvas_item_w2i_matrix (GnomeCanvasItem *item, cairo_matrix_t *matrix);
 
 /* Gets the affine transform that converts from item-relative coordinates to
  * canvas pixel coordinates.
  */
-void gnome_canvas_item_i2c_affine (GnomeCanvasItem *item, gdouble affine[6]);
+void gnome_canvas_item_i2c_matrix (GnomeCanvasItem *item, cairo_matrix_t *matrix);
 
 /* Remove the item from its parent group and make the new group its parent.  The
  * item will be put on top of all the items in the new group.  The item's
@@ -395,9 +353,6 @@ struct _GnomeCanvas {
 	/* Root canvas group */
 	GnomeCanvasItem *root;
 
-	/* Area that needs redrawing, stored as a microtile array */
-	ArtUta *redraw_area;
-
 	/* The item containing the mouse pointer, or NULL if none */
 	GnomeCanvasItem *current_item;
 
@@ -410,9 +365,6 @@ struct _GnomeCanvas {
 	/* If non-NULL, the currently focused item */
 	GnomeCanvasItem *focused_item;
 
-	/* GC for temporary draw pixmap */
-	GdkGC *pixmap_gc;
-
 	/* Event on which selection of current item is based */
 	GdkEvent pick_event;
 
@@ -420,21 +372,9 @@ struct _GnomeCanvas {
 	gdouble scroll_x1, scroll_y1;
 	gdouble scroll_x2, scroll_y2;
 
-	/* Scaling factor to be used for display */
-	gdouble pixels_per_unit;
-
 	/* Idle handler ID */
 	guint idle_id;
 
-	/* Signal handler ID for destruction of the root item */
-	guint root_destroy_id;
-
-	/* Area that is being redrawn.  Contains (x1, y1) but not (x2, y2).
-	 * Specified in canvas pixel coordinates.
-	 */
-	gint redraw_x1, redraw_y1;
-	gint redraw_x2, redraw_y2;
-
 	/* Offsets of the temprary drawing pixmap */
 	gint draw_xofs, draw_yofs;
 
@@ -447,20 +387,9 @@ struct _GnomeCanvas {
 	/* Event mask specified when grabbing an item */
 	guint grabbed_event_mask;
 
-	/* Tolerance distance for picking items */
-	gint close_enough;
-
-	/* Whether the canvas should center the scroll region in the middle of
-	 * the window if the scroll region is smaller than the window.
-	 */
-	guint center_scroll_region : 1;
-
 	/* Whether items need update at next idle loop iteration */
 	guint need_update : 1;
 
-	/* Whether the canvas needs redrawing at the next idle loop iteration */
-	guint need_redraw : 1;
-
 	/* Whether current item will be repicked at next idle loop iteration */
 	guint need_repick : 1;
 
@@ -469,12 +398,6 @@ struct _GnomeCanvas {
 
 	/* For use by internal pick_current_item() function */
 	guint in_repick : 1;
-
-	/* Whether the canvas is in antialiased mode or not */
-	guint aa : 1;
-
-	/* Which dither mode to use for antialiased mode drawing */
-	GdkRgbDither dither;
 };
 
 struct _GnomeCanvasClass {
@@ -483,20 +406,14 @@ struct _GnomeCanvasClass {
 	/* Draw the background for the area given. This method is only used
 	 * for non-antialiased canvases.
 	 */
-	void (* draw_background) (GnomeCanvas *canvas, GdkDrawable *drawable,
+	void (* draw_background) (GnomeCanvas *canvas, cairo_t *cr,
 				  gint x, gint y, gint width, gint height);
 
-	/* Render the background for the buffer given. The buf data structure
-	 * contains both a pointer to a packed 24-bit RGB array, and the
-	 * coordinates. This method is only used for antialiased canvases.
-	 */
-	void (* render_background) (GnomeCanvas *canvas, GnomeCanvasBuf *buf);
-
 	/* Private Virtual methods for groping the canvas inside bonobo */
 	void (* request_update) (GnomeCanvas *canvas);
 
 	/* Reserved for future expansion */
-	gpointer spare_vmethods [4];
+	gpointer spare_vmethods[4];
 };
 
 GType gnome_canvas_get_type (void) G_GNUC_CONST;
@@ -510,13 +427,6 @@ GType gnome_canvas_get_type (void) G_GNUC_CONST;
  */
 GtkWidget *gnome_canvas_new (void);
 
-/* Creates a new antialiased empty canvas.  You should push the GdkRgb colormap
- * and visual for this.
- */
-#ifndef GNOME_EXCLUDE_EXPERIMENTAL
-GtkWidget *gnome_canvas_new_aa (void);
-#endif
-
 /* Returns the root canvas item group of the canvas */
 GnomeCanvasGroup *gnome_canvas_root (GnomeCanvas *canvas);
 
@@ -528,15 +438,6 @@ void gnome_canvas_set_scroll_region (GnomeCanvas *canvas,
 void gnome_canvas_get_scroll_region (GnomeCanvas *canvas,
 				     gdouble *x1, gdouble *y1, gdouble *x2, gdouble *y2);
 
-/* Whether the canvas centers the scroll region if it is smaller than the window */
-void gnome_canvas_set_center_scroll_region (GnomeCanvas *canvas, gboolean center_scroll_region);
-
-/* Returns whether the canvas is set to center the scroll region if it is smaller than the window */
-gboolean gnome_canvas_get_center_scroll_region (GnomeCanvas *canvas);
-
-/* Sets the number of pixels that correspond to one unit in world coordinates */
-void gnome_canvas_set_pixels_per_unit (GnomeCanvas *canvas, gdouble n);
-
 /* Scrolls the canvas to the specified offsets, given in canvas pixel coordinates */
 void gnome_canvas_scroll_to (GnomeCanvas *canvas, gint cx, gint cy);
 
@@ -546,22 +447,11 @@ void gnome_canvas_scroll_to (GnomeCanvas *canvas, gint cx, gint cy);
  */
 void gnome_canvas_get_scroll_offsets (GnomeCanvas *canvas, gint *cx, gint *cy);
 
-/* Requests that the canvas be repainted immediately instead of in the idle
- * loop.
- */
-void gnome_canvas_update_now (GnomeCanvas *canvas);
-
 /* Returns the item that is at the specified position in world coordinates, or
  * NULL if no item is there.
  */
 GnomeCanvasItem *gnome_canvas_get_item_at (GnomeCanvas *canvas, gdouble x, gdouble y);
 
-/* For use only by item type implementations. Request that the canvas eventually
- * redraw the specified region. The region is specified as a microtile
- * array. This function takes over responsibility for freeing the uta argument.
- */
-void gnome_canvas_request_redraw_uta (GnomeCanvas *canvas, ArtUta *uta);
-
 /* For use only by item type implementations.  Request that the canvas
  * eventually redraw the specified region, specified in canvas pixel
  * coordinates.  The region contains (x1, y1) but not (x2, y2).
@@ -571,7 +461,8 @@ void gnome_canvas_request_redraw (GnomeCanvas *canvas, gint x1, gint y1, gint x2
 /* Gets the affine transform that converts world coordinates into canvas pixel
  * coordinates.
  */
-void gnome_canvas_w2c_affine (GnomeCanvas *canvas, gdouble affine[6]);
+void gnome_canvas_w2c_matrix (GnomeCanvas *canvas, cairo_matrix_t *matrix);
+void gnome_canvas_c2w_matrix (GnomeCanvas *canvas, cairo_matrix_t *matrix);
 
 /* These functions convert from a coordinate system to another.  "w" is world
  * coordinates, "c" is canvas pixel coordinates (pixel coordinates that are
@@ -592,32 +483,6 @@ void gnome_canvas_window_to_world (GnomeCanvas *canvas,
 void gnome_canvas_world_to_window (GnomeCanvas *canvas,
 				   gdouble worldx, gdouble worldy, gdouble *winx, gdouble *winy);
 
-/* Takes a string specification for a color and allocates it into the specified
- * GdkColor.  If the string is null, then it returns FALSE. Otherwise, it
- * returns TRUE.
- */
-gint gnome_canvas_get_color (GnomeCanvas *canvas, const gchar *spec, GdkColor *color);
-
-/* Allocates a color from the RGB value passed into this function. */
-gulong gnome_canvas_get_color_pixel (GnomeCanvas *canvas,
-				     guint        rgba);
-
-/* Sets the stipple origin of the specified gc so that it will be aligned with
- * all the stipples used in the specified canvas.  This is intended for use only
- * by canvas item implementations.
- */
-void gnome_canvas_set_stipple_origin (GnomeCanvas *canvas, GdkGC *gc);
-
-/* Controls the dithering used when the canvas renders.
- * Only applicable to antialiased canvases - ignored by non-antialiased canvases.
- */
-void gnome_canvas_set_dither (GnomeCanvas *canvas, GdkRgbDither dither);
-
-/* Returns the dither mode of an antialiased canvas.
- * Only applicable to antialiased canvases - ignored by non-antialiased canvases.
- */
-GdkRgbDither gnome_canvas_get_dither (GnomeCanvas *canvas);
-
 G_END_DECLS
 
 #endif
