@@ -179,10 +179,10 @@ ask_confirm_for_only_bcc (EMsgComposer *composer,
                           gboolean hidden_list_case)
 {
 	/* If the user is mailing a hidden contact list, it is possible for
-	   them to create a message with only Bcc recipients without really
-	   realizing it.  To try to avoid being totally confusing, I've changed
-	   this dialog to provide slightly different text in that case, to
-	   better explain what the hell is going on. */
+	 * them to create a message with only Bcc recipients without really
+	 * realizing it.  To try to avoid being totally confusing, I've changed
+	 * this dialog to provide slightly different text in that case, to
+	 * better explain what the hell is going on. */
 
 	return em_utils_prompt_user (
 		GTK_WINDOW (composer),
@@ -992,7 +992,7 @@ em_utils_compose_new_message_with_mailto (EShell *shell,
 {
 	EMsgComposer *composer;
 	EComposerHeaderTable *table;
-	EAccount *account = NULL;
+	CamelService *service = NULL;
 
 	g_return_val_if_fail (E_IS_SHELL (shell), NULL);
 
@@ -1008,15 +1008,17 @@ em_utils_compose_new_message_with_mailto (EShell *shell,
 
 	if (folder != NULL) {
 		CamelStore *store;
-		const gchar *uid;
 
 		store = camel_folder_get_parent_store (folder);
-		uid = camel_service_get_uid (CAMEL_SERVICE (store));
-		account = e_get_account_by_uid (uid);
+		service = CAMEL_SERVICE (store);
 	}
 
-	if (account != NULL)
-		e_composer_header_table_set_account_name (table, account->name);
+	if (service != NULL) {
+		const gchar *display_name;
+
+		display_name = camel_service_get_display_name (service);
+		e_composer_header_table_set_account_name (table, display_name);
+	}
 
 	composer_set_no_change (composer);
 
@@ -1026,7 +1028,9 @@ em_utils_compose_new_message_with_mailto (EShell *shell,
 }
 
 static gboolean
-replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
+replace_variables (GSList *clues,
+                   CamelMimeMessage *message,
+                   gchar **pstr)
 {
 	gint i;
 	gboolean string_changed = FALSE, count1 = FALSE;
@@ -1055,7 +1059,7 @@ replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
 
 			for (list = clues; list; list = g_slist_next (list)) {
 				gchar **temp = g_strsplit (list->data, "=", 2);
-				if (!g_ascii_strcasecmp (temp[0], out+1)) {
+				if (!g_ascii_strcasecmp (temp[0], out + 1)) {
 					g_free (str);
 					str = g_strconcat (temp_str[0], temp[1], temp_str[1], NULL);
 					count1 = TRUE;
@@ -1066,7 +1070,7 @@ replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
 			}
 
 			if (!count1) {
-				if (getenv (out+1)) {
+				if (getenv (out + 1)) {
 					g_free (str);
 					str = g_strconcat (
 						temp_str[0],
@@ -1111,7 +1115,9 @@ replace_variables (GSList *clues, CamelMimeMessage *message, gchar **pstr)
 }
 
 static void
-traverse_parts (GSList *clues, CamelMimeMessage *message, CamelDataWrapper *content)
+traverse_parts (GSList *clues,
+                CamelMimeMessage *message,
+                CamelDataWrapper *content)
 {
 	g_return_if_fail (message != NULL);
 
@@ -1399,7 +1405,8 @@ em_utils_edit_messages (EMailReader *reader,
 }
 
 static void
-emu_update_composers_security (EMsgComposer *composer, guint32 validity_found)
+emu_update_composers_security (EMsgComposer *composer,
+                               guint32 validity_found)
 {
 	GtkToggleAction *action;
 
@@ -1424,7 +1431,8 @@ emu_update_composers_security (EMsgComposer *composer, guint32 validity_found)
 }
 
 static void
-real_update_forwarded_flag (gpointer uid, gpointer folder)
+real_update_forwarded_flag (gpointer uid,
+                            gpointer folder)
 {
 	if (uid && folder)
 		camel_folder_set_message_flags (
@@ -1780,27 +1788,27 @@ static EMsgComposer *
 redirect_get_composer (EShell *shell,
                        CamelMimeMessage *message)
 {
-	EMsgComposer *composer;
+	CamelMedium *medium;
 	EAccount *account;
 
+	medium = CAMEL_MEDIUM (message);
+
 	/* QMail will refuse to send a message if it finds one of
-	   it's Delivered-To headers in the message, so remove all
-	   Delivered-To headers. Fixes bug #23635. */
-	while (camel_medium_get_header (CAMEL_MEDIUM (message), "Delivered-To"))
-		camel_medium_remove_header (CAMEL_MEDIUM (message), "Delivered-To");
+	 * it's Delivered-To headers in the message, so remove all
+	 * Delivered-To headers. Fixes bug #23635. */
+	while (camel_medium_get_header (medium, "Delivered-To"))
+		camel_medium_remove_header (medium, "Delivered-To");
 
-	while (camel_medium_get_header (CAMEL_MEDIUM (message), "Bcc"))
-		camel_medium_remove_header (CAMEL_MEDIUM (message), "Bcc");
+	while (camel_medium_get_header (medium, "Bcc"))
+		camel_medium_remove_header (medium, "Bcc");
 
-	while (camel_medium_get_header (CAMEL_MEDIUM (message), "Resent-Bcc"))
-		camel_medium_remove_header (CAMEL_MEDIUM (message), "Resent-Bcc");
+	while (camel_medium_get_header (medium, "Resent-Bcc"))
+		camel_medium_remove_header (medium, "Resent-Bcc");
 
 	account = em_utils_guess_account_with_recipients (message, NULL);
 
-	composer = e_msg_composer_new_redirect (
+	return e_msg_composer_new_redirect (
 		shell, message, account ? account->name : NULL, NULL);
-
-	return composer;
 }
 
 /**
@@ -1965,9 +1973,10 @@ em_utils_send_receipt (EMailSession *session,
 		message_date ="";
 
 	/* Create toplevel container */
-	camel_data_wrapper_set_mime_type (CAMEL_DATA_WRAPPER (body),
-					  "multipart/report;"
-					  "report-type=\"disposition-notification\"");
+	camel_data_wrapper_set_mime_type (
+		CAMEL_DATA_WRAPPER (body),
+		"multipart/report;"
+		"report-type=\"disposition-notification\"");
 	camel_multipart_set_boundary (body, NULL);
 
 	/* Create textual receipt */
@@ -2034,7 +2043,8 @@ em_utils_send_receipt (EMailSession *session,
 	g_object_unref (part);
 
 	/* Finish creating the message */
-	camel_medium_set_content (CAMEL_MEDIUM (receipt), CAMEL_DATA_WRAPPER (body));
+	camel_medium_set_content (
+		CAMEL_MEDIUM (receipt), CAMEL_DATA_WRAPPER (body));
 	g_object_unref (body);
 
 	/* Translators: %s is the subject of the email message */
@@ -2050,7 +2060,8 @@ em_utils_send_receipt (EMailSession *session,
 
 	addr = camel_internet_address_new ();
 	camel_address_decode (CAMEL_ADDRESS (addr), receipt_address);
-	camel_mime_message_set_recipients (receipt, CAMEL_RECIPIENT_TYPE_TO, addr);
+	camel_mime_message_set_recipients (
+		receipt, CAMEL_RECIPIENT_TYPE_TO, addr);
 	g_object_unref (addr);
 
 	transport_uid = g_strconcat (account->uid, "-transport", NULL);
@@ -2137,12 +2148,17 @@ reply_get_composer (EShell *shell,
 	EDestination **tov, **ccv;
 	EMsgComposer *composer;
 	EComposerHeaderTable *table;
+	CamelMedium *medium;
 	gchar *subject;
 
 	g_return_val_if_fail (E_IS_SHELL (shell), NULL);
 	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
-	g_return_val_if_fail (to == NULL || CAMEL_IS_INTERNET_ADDRESS (to), NULL);
-	g_return_val_if_fail (cc == NULL || CAMEL_IS_INTERNET_ADDRESS (cc), NULL);
+
+	if (to != NULL)
+		g_return_val_if_fail (CAMEL_IS_INTERNET_ADDRESS (to), NULL);
+
+	if (cc != NULL)
+		g_return_val_if_fail (CAMEL_IS_INTERNET_ADDRESS (cc), NULL);
 
 	composer = e_msg_composer_new (shell);
 
@@ -2194,7 +2210,7 @@ reply_get_composer (EShell *shell,
 			store_url = camel_url_to_string (
 				url, CAMEL_URL_HIDE_ALL);
 			if (store_url[strlen (store_url) - 1] == '/')
-				store_url[strlen (store_url)-1] = '\0';
+				store_url[strlen (store_url) - 1] = '\0';
 		}
 
 		post = camel_address_encode ((CamelAddress *) postto);
@@ -2205,29 +2221,38 @@ reply_get_composer (EShell *shell,
 	}
 
 	/* Add In-Reply-To and References. */
-	message_id = camel_medium_get_header (CAMEL_MEDIUM (message), "Message-ID");
-	references = camel_medium_get_header (CAMEL_MEDIUM (message), "References");
-	if (message_id) {
+
+	medium = CAMEL_MEDIUM (message);
+	message_id = camel_medium_get_header (medium, "Message-ID");
+	references = camel_medium_get_header (medium, "References");
+
+	if (message_id != NULL) {
 		gchar *reply_refs;
 
-		e_msg_composer_add_header (composer, "In-Reply-To", message_id);
+		e_msg_composer_add_header (
+			composer, "In-Reply-To", message_id);
 
 		if (references)
-			reply_refs = g_strdup_printf ("%s %s", references, message_id);
+			reply_refs = g_strdup_printf (
+				"%s %s", references, message_id);
 		else
 			reply_refs = g_strdup (message_id);
 
-		e_msg_composer_add_header (composer, "References", reply_refs);
+		e_msg_composer_add_header (
+			composer, "References", reply_refs);
 		g_free (reply_refs);
-	} else if (references) {
-		e_msg_composer_add_header (composer, "References", references);
+
+	} else if (references != NULL) {
+		e_msg_composer_add_header (
+			composer, "References", references);
 	}
 
 	return composer;
 }
 
 static gboolean
-get_reply_list (CamelMimeMessage *message, CamelInternetAddress *to)
+get_reply_list (CamelMimeMessage *message,
+                CamelInternetAddress *to)
 {
 	const gchar *header, *p;
 	gchar *addr;
@@ -2553,7 +2578,9 @@ typedef void		(*AttribFormatter)	(GString *str,
 						 CamelMimeMessage *message);
 
 static void
-format_sender (GString *str, const gchar *attr, CamelMimeMessage *message)
+format_sender (GString *str,
+               const gchar *attr,
+               CamelMimeMessage *message)
 {
 	CamelInternetAddress *sender;
 	const gchar *name, *addr = NULL;
@@ -2803,8 +2830,8 @@ composer_set_body (EMsgComposer *composer,
 		const gchar *key;
 
 		/* If we are placing signature on top, then move cursor to the end,
-		   otherwise try to find the signature place and place cursor just
-		   before the signature. We added there an empty line already. */
+		 * otherwise try to find the signature place and place cursor just
+		 * before the signature. We added there an empty line already. */
 		gtkhtml_editor_run_command (editor, "block-selection");
 		gtkhtml_editor_run_command (editor, "cursor-bod");
 
@@ -2826,7 +2853,8 @@ composer_set_body (EMsgComposer *composer,
 }
 
 gchar *
-em_utils_construct_composer_text (CamelMimeMessage *message, EMFormat *source)
+em_utils_construct_composer_text (CamelMimeMessage *message,
+                                  EMFormat *source)
 {
 	gchar *text, *credits;
 	gboolean start_bottom = 0;
@@ -2863,8 +2891,8 @@ em_utils_reply_to_message (EShell *shell,
                            const gchar *message_uid,
                            EMailReplyType type,
                            EMailReplyStyle style,
-                           EMFormat *source,
-			   CamelInternetAddress *address)
+                           EMFormat *source_formatter,
+                           CamelInternetAddress *address)
 {
 	CamelInternetAddress *to, *cc;
 	CamelNNTPAddress *postto = NULL;
@@ -2923,7 +2951,7 @@ em_utils_reply_to_message (EShell *shell,
 	g_object_unref (to);
 	g_object_unref (cc);
 
-	composer_set_body (composer, message, style, source);
+	composer_set_body (composer, message, style, source_formatter);
 
 	if (folder != NULL) {
 		gchar *folder_uri;
