@@ -39,7 +39,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
-#include "e-util/e-account-utils.h"
 #include "e-util/e-mktemp.h"
 #include "e-util/e-icon-factory.h"
 #include "e-util/e-alert-dialog.h"
@@ -496,10 +495,9 @@ folder_tree_expand_node (const gchar *key,
 	GtkTreeView *tree_view;
 	GtkTreeModel *model;
 	GtkTreePath *path;
-	EAccount *account;
 	EMailBackend *backend;
 	EMailSession *session;
-	CamelStore *store;
+	CamelService *service;
 	const gchar *p;
 	gchar *uid;
 	gsize n;
@@ -520,36 +518,21 @@ folder_tree_expand_node (const gchar *key,
 	backend = em_folder_tree_get_backend (folder_tree);
 	session = e_mail_backend_get_session (backend);
 
-	if ((account = e_get_account_by_uid (uid)) && account->enabled) {
-		store = (CamelStore *) camel_session_get_service (
-			CAMEL_SESSION (session), account->uid);
+	service = camel_session_get_service (CAMEL_SESSION (session), uid);
 
-		if (store == NULL)
-			return;
-
-		g_object_ref (store);
-	} else if (!strcmp (uid, "vfolder")) {
-		if (!(store = vfolder_store))
-			return;
-
-		g_object_ref (store);
-	} else if (!strcmp (uid, "local")) {
-		if (!(store = e_mail_local_get_store ()))
-			return;
-
-		g_object_ref (store);
-	} else {
+	if (!CAMEL_IS_STORE (service))
 		return;
-	}
+
+	g_object_ref (service);
 
 	si = em_folder_tree_model_lookup_store_info (
-		EM_FOLDER_TREE_MODEL (model), store);
+		EM_FOLDER_TREE_MODEL (model), CAMEL_STORE (service));
 	if (si == NULL) {
-		g_object_unref (store);
+		g_object_unref (service);
 		return;
 	}
 
-	g_object_unref (store);
+	g_object_unref (service);
 
 	if (p != NULL) {
 		if (!(row = g_hash_table_lookup (si->full_hash, p + 1)))
@@ -706,7 +689,8 @@ exit:
 }
 
 static gboolean
-subdirs_contain_unread (GtkTreeModel *model, GtkTreeIter *root)
+subdirs_contain_unread (GtkTreeModel *model,
+                        GtkTreeIter *root)
 {
 	guint unread;
 	GtkTreeIter iter;
@@ -2028,9 +2012,9 @@ struct _DragDataReceivedAsync {
 	guint32 action;
 	guint info;
 
-	guint move:1;
-	guint moved:1;
-	guint aborted:1;
+	guint move : 1;
+	guint moved : 1;
+	guint aborted : 1;
 };
 
 static void
@@ -2335,7 +2319,7 @@ folder_tree_drop_target (EMFolderTree *folder_tree,
 					COL_UINT_FLAGS, &src_flags, -1);
 
 			/* can't dnd onto itself or below itself - bad things happen,
-			   no point dragging to where we were either */
+			 * no point dragging to where we were either */
 			if (gtk_tree_path_compare (path, src_path) == 0
 			    || gtk_tree_path_is_descendant (path, src_path)
 			    || (gtk_tree_path_is_ancestor (path, src_path)
@@ -2733,10 +2717,10 @@ em_folder_tree_enable_drag_and_drop (EMFolderTree *folder_tree)
 	tree_view = GTK_TREE_VIEW (folder_tree);
 
 	if (!setup) {
-		for (i=0; i<NUM_DRAG_TYPES; i++)
+		for (i = 0; i < NUM_DRAG_TYPES; i++)
 			drag_atoms[i] = gdk_atom_intern (drag_types[i].target, FALSE);
 
-		for (i=0; i<NUM_DROP_TYPES; i++)
+		for (i = 0; i < NUM_DROP_TYPES; i++)
 			drop_atoms[i] = gdk_atom_intern (drop_types[i].target, FALSE);
 
 		setup = 1;
@@ -2776,7 +2760,8 @@ em_folder_tree_enable_drag_and_drop (EMFolderTree *folder_tree)
 }
 
 void
-em_folder_tree_set_excluded (EMFolderTree *folder_tree, guint32 flags)
+em_folder_tree_set_excluded (EMFolderTree *folder_tree,
+                             guint32 flags)
 {
 	g_return_if_fail (EM_IS_FOLDER_TREE (folder_tree));
 
@@ -2815,7 +2800,7 @@ em_folder_tree_get_selected_uris (EMFolderTree *folder_tree)
 	}
 
 	rows = gtk_tree_selection_get_selected_rows (selection, &model);
-	for (l=rows; l; l=g_list_next (l)) {
+	for (l = rows; l; l = g_list_next (l)) {
 		GtkTreeIter iter;
 		GtkTreePath *path = l->data;
 
@@ -2877,7 +2862,7 @@ em_folder_tree_set_selected_list (EMFolderTree *folder_tree,
 	if (!expand_only)
 		folder_tree_clear_selected_list (folder_tree);
 
-	for (;list;list = list->next) {
+	for (; list; list = list->next) {
 		CamelStore *store;
 		struct _selected_uri *u;
 		const gchar *folder_uri;
@@ -2928,7 +2913,8 @@ em_folder_tree_set_selected_list (EMFolderTree *folder_tree,
 
 #if 0
 static void
-dump_fi (CamelFolderInfo *fi, gint depth)
+dump_fi (CamelFolderInfo *fi,
+         gint depth)
 {
 	gint i;
 
@@ -2963,7 +2949,8 @@ em_folder_tree_set_selected (EMFolderTree *folder_tree,
 }
 
 void
-em_folder_tree_select_next_path (EMFolderTree *folder_tree, gboolean skip_read_folders)
+em_folder_tree_select_next_path (EMFolderTree *folder_tree,
+                                 gboolean skip_read_folders)
 {
 	GtkTreeView *tree_view;
 	GtkTreeSelection *selection;
@@ -3229,7 +3216,8 @@ em_folder_tree_get_selected (EMFolderTree *folder_tree,
 }
 
 gboolean
-em_folder_tree_store_root_selected (EMFolderTree *folder_tree, CamelStore **out_store)
+em_folder_tree_store_root_selected (EMFolderTree *folder_tree,
+                                    CamelStore **out_store)
 {
 	GtkTreeView *tree_view;
 	GtkTreeSelection *selection;
@@ -3308,15 +3296,14 @@ em_folder_tree_get_selected_folder (EMFolderTree *folder_tree)
 	return folder;
 }
 
-EAccount *
-em_folder_tree_get_selected_account (EMFolderTree *folder_tree)
+CamelStore *
+em_folder_tree_get_selected_store (EMFolderTree *folder_tree)
 {
 	GtkTreeView *tree_view;
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	CamelStore *store = NULL;
-	const gchar *uid = NULL;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE (folder_tree), NULL);
 
@@ -3331,21 +3318,20 @@ em_folder_tree_get_selected_account (EMFolderTree *folder_tree)
 			model, &iter,
 			COL_POINTER_CAMEL_STORE, &store, -1);
 
-	if (CAMEL_IS_STORE (store))
-		uid = camel_service_get_uid (CAMEL_SERVICE (store));
-
-	return (uid != NULL) ? e_get_account_by_uid (uid) : NULL;
+	return CAMEL_IS_STORE (store) ? store : NULL;
 }
 
 void
-em_folder_tree_set_skip_double_click (EMFolderTree *folder_tree, gboolean skip)
+em_folder_tree_set_skip_double_click (EMFolderTree *folder_tree,
+                                      gboolean skip)
 {
 	folder_tree->priv->skip_double_click = skip;
 }
 
 /* stores come first, then by uri */
 static gint
-sort_by_store_and_uri (gconstpointer name1, gconstpointer name2)
+sort_by_store_and_uri (gconstpointer name1,
+                       gconstpointer name2)
 {
 	const gchar *n1 = name1, *n2 = name2;
 	gboolean is_store1, is_store2;
