@@ -34,12 +34,19 @@ typedef void (*MboxImporterCreatePreviewFunc)(GObject *preview, GtkWidget **prev
 typedef void (*MboxImporterFillPreviewFunc)(GObject *preview, CamelMimeMessage *msg);
 
 /* 'create_func' is a function to create a view. 'fill_func' is to fill view with a preview of a message 'msg'
-   (mail importer cannot link to em-format-html-display directly) */
+ * (mail importer cannot link to em-format-html-display directly) */
 void mbox_importer_set_preview_funcs (MboxImporterCreatePreviewFunc create_func, MboxImporterFillPreviewFunc fill_func);
 
 EImportImporter *elm_importer_peek (void);
 EImportImporter *pine_importer_peek (void);
 
+/* Defines copied from nsMsgMessageFlags.h in Mozilla source. */
+/* Evolution only cares about these headers I think */
+#define MSG_FLAG_READ 0x0001
+#define MSG_FLAG_REPLIED 0x0002
+#define MSG_FLAG_MARKED 0x0004
+#define MSG_FLAG_EXPUNGED 0x0008
+
 gint		mail_importer_import_mbox	(EMailSession *session,
 						 const gchar *path,
 						 const gchar *folderuri,
