@@ -19,21 +19,25 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-memo-shell-backend.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <libecal/e-cal.h>
+#include <libecal/e-cal-client.h>
 #include <libedataserver/e-url.h>
 #include <libedataserver/e-source.h>
 #include <libedataserver/e-source-list.h>
 #include <libedataserver/e-source-group.h>
+#include <libedataserverui/e-client-utils.h>
 
 #include "shell/e-shell.h"
 #include "shell/e-shell-backend.h"
 #include "shell/e-shell-window.h"
 
-#include "calendar/common/authentication.h"
 #include "calendar/gui/comp-util.h"
 #include "calendar/gui/dialogs/calendar-setup.h"
 #include "calendar/gui/dialogs/memo-editor.h"
@@ -71,6 +75,7 @@ memo_shell_backend_ensure_sources (EShellBackend *shell_backend)
 	GSList *sources, *iter;
 	const gchar *name;
 	gboolean save_list = FALSE;
+	GError *error = NULL;
 
 	personal = NULL;
 
@@ -79,10 +84,15 @@ memo_shell_backend_ensure_sources (EShellBackend *shell_backend)
 	shell = e_shell_backend_get_shell (shell_backend);
 	shell_settings = e_shell_get_shell_settings (shell);
 
-	if (!e_cal_get_sources (
+	e_cal_client_get_sources (
 		&memo_shell_backend->priv->source_list,
-		E_CAL_SOURCE_TYPE_JOURNAL, NULL)) {
-		g_warning ("Could not get memo sources from GConf!");
+		E_CAL_CLIENT_SOURCE_TYPE_MEMOS, &error);
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Could not get memo sources: %s",
+			G_STRFUNC, error->message);
+		g_error_free (error);
 		return;
 	}
 
@@ -160,43 +170,58 @@ memo_shell_backend_new_memo (ESource *source,
                              EShell *shell,
                              CompEditorFlags flags)
 {
-	ECal *cal;
+	EClient *client = NULL;
+	ECalClient *cal_client;
 	ECalComponent *comp;
 	CompEditor *editor;
+	GError *error = NULL;
+
+	e_client_utils_open_new_finish (source, result, &client, &error);
 
 	/* XXX Handle errors better. */
-	cal = e_load_cal_source_finish (source, result, NULL);
-	g_return_if_fail (E_IS_CAL (cal));
+	if (error != NULL) {
+		g_warn_if_fail (client == NULL);
+		g_warning (
+			"%s: Failed to open '%s': %s",
+			G_STRFUNC, e_source_peek_name (source),
+			error->message);
+		g_error_free (error);
+		return;
+	}
 
-	comp = cal_comp_memo_new_with_defaults (cal);
+	g_return_if_fail (E_IS_CAL_CLIENT (client));
+
+	cal_client = E_CAL_CLIENT (client);
+	comp = cal_comp_memo_new_with_defaults (cal_client);
 	cal_comp_update_time_by_active_window (comp, shell);
-	editor = memo_editor_new (cal, shell, flags);
+	editor = memo_editor_new (cal_client, shell, flags);
 	comp_editor_edit_comp (editor, comp);
 
 	gtk_window_present (GTK_WINDOW (editor));
 
 	g_object_unref (comp);
-	g_object_unref (cal);
+	g_object_unref (client);
 }
 
 static void
-memo_shell_backend_memo_new_cb (ESource *source,
+memo_shell_backend_memo_new_cb (GObject *source_object,
                                 GAsyncResult *result,
-                                EShell *shell)
+                                gpointer shell)
 {
 	CompEditorFlags flags = 0;
 
 	flags |= COMP_EDITOR_NEW_ITEM;
 
-	memo_shell_backend_new_memo (source, result, shell, flags);
+	memo_shell_backend_new_memo (
+		E_SOURCE (source_object), result, shell, flags);
 
 	g_object_unref (shell);
 }
 
 static void
-memo_shell_backend_memo_shared_new_cb (ESource *source,
+memo_shell_backend_memo_shared_new_cb (GObject *source_object,
                                        GAsyncResult *result,
-                                       EShell *shell)
+                                       gpointer shell)
 {
 	CompEditorFlags flags = 0;
 
@@ -204,7 +229,8 @@ memo_shell_backend_memo_shared_new_cb (ESource *source,
 	flags |= COMP_EDITOR_IS_SHARED;
 	flags |= COMP_EDITOR_USER_ORG;
 
-	memo_shell_backend_new_memo (source, result, shell, flags);
+	memo_shell_backend_new_memo (
+		E_SOURCE (source_object), result, shell, flags);
 
 	g_object_unref (shell);
 }
@@ -218,14 +244,11 @@ action_memo_new_cb (GtkAction *action,
 	EShellSettings *shell_settings;
 	ESource *source = NULL;
 	ESourceList *source_list;
-	ECalSourceType source_type;
 	const gchar *action_name;
 	gchar *uid;
 
 	/* This callback is used for both memos and shared memos. */
 
-	source_type = E_CAL_SOURCE_TYPE_JOURNAL;
-
 	shell = e_shell_window_get_shell (shell_window);
 	shell_settings = e_shell_get_shell_settings (shell);
 	shell_backend = e_shell_get_backend_by_name (shell, "memos");
@@ -250,19 +273,13 @@ action_memo_new_cb (GtkAction *action,
 	 * FIXME Need to obtain a better default time zone. */
 	action_name = gtk_action_get_name (action);
 	if (g_strcmp0 (action_name, "memo-shared-new") == 0)
-		e_load_cal_source_async (
-			source, source_type, NULL,
-			GTK_WINDOW (shell_window),
-			NULL, (GAsyncReadyCallback)
-			memo_shell_backend_memo_shared_new_cb,
-			g_object_ref (shell));
+		e_client_utils_open_new (source, E_CLIENT_SOURCE_TYPE_MEMOS, FALSE, NULL,
+			e_client_utils_authenticate_handler, GTK_WINDOW (shell_window),
+			memo_shell_backend_memo_shared_new_cb, g_object_ref (shell));
 	else
-		e_load_cal_source_async (
-			source, source_type, NULL,
-			GTK_WINDOW (shell_window),
-			NULL, (GAsyncReadyCallback)
-			memo_shell_backend_memo_new_cb,
-			g_object_ref (shell));
+		e_client_utils_open_new (source, E_CLIENT_SOURCE_TYPE_MEMOS, FALSE, NULL,
+			e_client_utils_authenticate_handler, GTK_WINDOW (shell_window),
+			memo_shell_backend_memo_new_cb, g_object_ref (shell));
 
 	g_object_unref (source_list);
 }
@@ -308,11 +325,11 @@ memo_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 	EShell *shell;
 	CompEditor *editor;
 	CompEditorFlags flags = 0;
-	ECal *client;
+	ECalClient *client;
 	ECalComponent *comp;
 	ESource *source;
 	ESourceList *source_list;
-	ECalSourceType source_type;
+	ECalClientSourceType source_type;
 	EUri *euri;
 	icalcomponent *icalcomp;
 	const gchar *cp;
@@ -322,7 +339,7 @@ memo_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 	gboolean handled = FALSE;
 	GError *error = NULL;
 
-	source_type = E_CAL_SOURCE_TYPE_JOURNAL;
+	source_type = E_CAL_CLIENT_SOURCE_TYPE_MEMOS;
 	shell = e_shell_backend_get_shell (shell_backend);
 
 	if (strncmp (uri, "memo:", 5) != 0)
@@ -375,8 +392,13 @@ memo_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 	 * we successfully open it is another matter... */
 	handled = TRUE;
 
-	if (!e_cal_get_sources (&source_list, source_type, NULL)) {
-		g_printerr ("Could not get memo sources from GConf!\n");
+	e_cal_client_get_sources (&source_list, source_type, &error);
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Could not get memo sources: %s",
+			G_STRFUNC, error->message);
+		g_clear_error (&error);
 		goto exit;
 	}
 
@@ -387,13 +409,21 @@ memo_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 		goto exit;
 	}
 
-	client = e_auth_new_cal_from_source (source, source_type);
-	if (client == NULL || !e_cal_open (client, TRUE, &error)) {
-		if (error != NULL) {
-			g_printerr ("%s\n", error->message);
-			g_error_free (error);
-		}
+	client = e_cal_client_new (source, source_type, &error);
+
+	if (client != NULL) {
+		g_signal_connect (
+			client, "authenticate",
+			G_CALLBACK (e_client_utils_authenticate_handler), NULL);
+		e_client_open_sync (E_CLIENT (client), TRUE, NULL, &error);
+	}
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Failed to create/open client: %s",
+			G_STRFUNC, error->message);
 		g_object_unref (source_list);
+		g_error_free (error);
 		goto exit;
 	}
 
@@ -405,15 +435,24 @@ memo_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 	if (editor != NULL)
 		goto present;
 
-	if (!e_cal_get_object (client, comp_uid, comp_rid, &icalcomp, &error)) {
-		g_printerr ("%s\n", error->message);
+	e_cal_client_get_object_sync (
+		client, comp_uid, comp_rid, &icalcomp, NULL, &error);
+
+	if (error != NULL) {
+		g_warning (
+			"%s: Failed to get object: %s",
+			G_STRFUNC, error->message);
 		g_object_unref (source_list);
 		g_error_free (error);
 		goto exit;
 	}
 
 	comp = e_cal_component_new ();
-	e_cal_component_set_icalcomponent (comp, icalcomp);
+	if (!e_cal_component_set_icalcomponent (comp, icalcomp)) {
+		g_warning ("%s: Failed to set icalcomp to comp\n", G_STRFUNC);
+		icalcomponent_free (icalcomp);
+		icalcomp = NULL;
+	}
 
 	if (e_cal_component_has_organizer (comp))
 		flags |= COMP_EDITOR_IS_SHARED;
