@@ -22,7 +22,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
@@ -33,18 +35,10 @@
 #include "gal-a11y-e-cell-toggle.h"
 #include "gal-a11y-e-cell-registry.h"
 #include "e-util/e-util.h"
-#include "misc/e-hsv-utils.h"
 
 #include "e-cell-toggle.h"
 #include "e-table-item.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
-#define E_CELL_TOGGLE_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE \
-	((obj), E_TYPE_CELL_TOGGLE, ECellTogglePrivate))
-
 struct _ECellTogglePrivate {
 	gchar **icon_names;
 	guint n_icon_names;
@@ -54,7 +48,7 @@ struct _ECellTogglePrivate {
 	gint height;
 };
 
-G_DEFINE_TYPE (ECellToggle, e_cell_toggle, E_CELL_TYPE)
+G_DEFINE_TYPE (ECellToggle, e_cell_toggle, E_TYPE_CELL)
 
 typedef struct {
 	ECellView cell_view;
@@ -103,7 +97,7 @@ cell_toggle_dispose (GObject *object)
 {
 	ECellTogglePrivate *priv;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (object);
+	priv = E_CELL_TOGGLE (object)->priv;
 
 	if (priv->empty != NULL) {
 		g_object_unref (priv->empty);
@@ -123,7 +117,7 @@ cell_toggle_finalize (GObject *object)
 	ECellTogglePrivate *priv;
 	guint ii;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (object);
+	priv = E_CELL_TOGGLE (object)->priv;
 
 	/* The array is not NULL-terminated,
 	 * so g_strfreev() will not work. */
@@ -173,7 +167,7 @@ cell_toggle_kill_view (ECellView *ecell_view)
 
 static void
 cell_toggle_draw (ECellView *ecell_view,
-                  GdkDrawable *drawable,
+                  cairo_t *cr,
                   gint model_col,
                   gint view_col,
                   gint row,
@@ -186,18 +180,14 @@ cell_toggle_draw (ECellView *ecell_view,
 	ECellTogglePrivate *priv;
 	GdkPixbuf *image;
 	gint x, y;
-	cairo_t *cr;
 
 	const gint value = GPOINTER_TO_INT (
 		 e_table_model_value_at (ecell_view->e_table_model, model_col, row));
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (ecell_view->ecell);
+	priv = E_CELL_TOGGLE (ecell_view->ecell)->priv;
 
-	if (value < 0 || value >= priv->pixbufs->len) {
-		g_warning ("Value from the table model is %d, the states we support are [0..%d)\n",
-			   value, priv->pixbufs->len);
+	if (value < 0 || value >= priv->pixbufs->len)
 		return;
-	}
 
 	image = g_ptr_array_index (priv->pixbufs, value);
 
@@ -211,13 +201,10 @@ cell_toggle_draw (ECellView *ecell_view,
 	else
 		y = y1 + ((y2 - y1) - gdk_pixbuf_get_height (image)) / 2;
 
-	cr = gdk_cairo_create (drawable);
 	cairo_save (cr);
 	gdk_cairo_set_source_pixbuf (cr, image, x, y);
 	cairo_paint_with_alpha (cr, 1);
 	cairo_restore (cr);
-	cairo_destroy (cr);
-
 }
 
 static void
@@ -229,7 +216,7 @@ etog_set_value (ECellToggleView *toggle_view,
 {
 	ECellTogglePrivate *priv;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (toggle_view->cell_view.ecell);
+	priv = E_CELL_TOGGLE (toggle_view->cell_view.ecell)->priv;
 
 	if (value >= priv->pixbufs->len)
 		value = 0;
@@ -249,7 +236,8 @@ cell_toggle_event (ECellView *ecell_view,
                    ECellActions *actions)
 {
 	ECellToggleView *toggle_view = (ECellToggleView *) ecell_view;
-	gpointer _value = e_table_model_value_at (ecell_view->e_table_model, model_col, row);
+	gpointer _value = e_table_model_value_at (
+		ecell_view->e_table_model, model_col, row);
 	const gint value = GPOINTER_TO_INT (_value);
 
 	switch (event->type) {
@@ -258,10 +246,13 @@ cell_toggle_event (ECellView *ecell_view,
 			return FALSE;
 		/* Fall through */
 	case GDK_BUTTON_PRESS:
-		if (!e_table_model_is_cell_editable (ecell_view->e_table_model, model_col, row))
+		if (!e_table_model_is_cell_editable (
+			ecell_view->e_table_model, model_col, row))
 			return FALSE;
 
-		etog_set_value (toggle_view, model_col, view_col, row, value + 1);
+		etog_set_value (
+			toggle_view, model_col, view_col, row, value + 1);
+
 		return TRUE;
 
 	default:
@@ -277,7 +268,7 @@ cell_toggle_height (ECellView *ecell_view,
 {
 	ECellTogglePrivate *priv;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (ecell_view->ecell);
+	priv = E_CELL_TOGGLE (ecell_view->ecell)->priv;
 
 	return priv->height;
 }
@@ -299,13 +290,10 @@ cell_toggle_print (ECellView *ecell_view,
 
 	cairo_t *cr;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (ecell_view->ecell);
+	priv = E_CELL_TOGGLE (ecell_view->ecell)->priv;
 
-	if (value >= priv->pixbufs->len) {
-		g_warning ("Value from the table model is %d, the states we support are [0..%d)\n",
-				value, priv->pixbufs->len);
+	if (value >= priv->pixbufs->len)
 		return;
-	}
 
 	image = g_ptr_array_index (priv->pixbufs, value);
 	if (image) {
@@ -313,8 +301,8 @@ cell_toggle_print (ECellView *ecell_view,
 		cairo_save (cr);
 		cairo_translate (cr, 0 , 0);
 		image = gdk_pixbuf_add_alpha (image, TRUE, 255, 255, 255);
-		image_width = (gdouble)gdk_pixbuf_get_width (image);
-		image_height = (gdouble)gdk_pixbuf_get_height (image);
+		image_width = (gdouble) gdk_pixbuf_get_width (image);
+		image_height = (gdouble) gdk_pixbuf_get_height (image);
 		cairo_rectangle (cr, image_width / 7, image_height / 3,
 				image_width - image_width / 4,
 				image_width - image_height / 7);
@@ -335,7 +323,7 @@ cell_toggle_print_height (ECellView *ecell_view,
 {
 	ECellTogglePrivate *priv;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (ecell_view->ecell);
+	priv = E_CELL_TOGGLE (ecell_view->ecell)->priv;
 
 	return priv->height;
 }
@@ -350,7 +338,7 @@ cell_toggle_max_width (ECellView *ecell_view,
 	gint number_of_rows;
 	gint row;
 
-	priv = E_CELL_TOGGLE_GET_PRIVATE (ecell_view->ecell);
+	priv = E_CELL_TOGGLE (ecell_view->ecell)->priv;
 
 	number_of_rows = e_table_model_row_count (ecell_view->e_table_model);
 	for (row = 0; row < number_of_rows; row++) {
@@ -397,7 +385,8 @@ e_cell_toggle_class_init (ECellToggleClass *class)
 static void
 e_cell_toggle_init (ECellToggle *cell_toggle)
 {
-	cell_toggle->priv = E_CELL_TOGGLE_GET_PRIVATE (cell_toggle);
+	cell_toggle->priv = G_TYPE_INSTANCE_GET_PRIVATE (
+		cell_toggle, E_TYPE_CELL_TOGGLE, ECellTogglePrivate);
 
 	cell_toggle->priv->empty =
 		gdk_pixbuf_new_from_xpm_data (empty_xpm);
