@@ -20,7 +20,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <stdlib.h>
 #include <string.h>
@@ -114,8 +116,8 @@ e_table_state_vanilla (gint col_count)
 }
 
 gboolean
-e_table_state_load_from_file    (ETableState *state,
-				 const gchar          *filename)
+e_table_state_load_from_file (ETableState *state,
+                              const gchar *filename)
 {
 	xmlDoc *doc;
 
@@ -133,8 +135,8 @@ e_table_state_load_from_file    (ETableState *state,
 }
 
 void
-e_table_state_load_from_string  (ETableState *state,
-				 const gchar          *xml)
+e_table_state_load_from_string (ETableState *state,
+                                const gchar *xml)
 {
 	xmlDoc *doc;
 
@@ -156,7 +158,7 @@ typedef struct {
 
 void
 e_table_state_load_from_node (ETableState *state,
-			      const xmlNode *node)
+                              const xmlNode *node)
 {
 	xmlNode *children;
 	GList *list = NULL, *iterator;
@@ -213,8 +215,8 @@ e_table_state_load_from_node (ETableState *state,
 }
 
 void
-e_table_state_save_to_file      (ETableState *state,
-				 const gchar          *filename)
+e_table_state_save_to_file (ETableState *state,
+                            const gchar *filename)
 {
 	xmlDoc *doc;
 
@@ -229,7 +231,7 @@ e_table_state_save_to_file      (ETableState *state,
 }
 
 gchar *
-e_table_state_save_to_string    (ETableState *state)
+e_table_state_save_to_string (ETableState *state)
 {
 	gchar *ret_val;
 	xmlChar *string;
@@ -243,14 +245,14 @@ e_table_state_save_to_string    (ETableState *state)
 	xmlDocDumpMemory (doc, &string, &length);
 	xmlFreeDoc (doc);
 
-	ret_val = g_strdup ((gchar *)string);
+	ret_val = g_strdup ((gchar *) string);
 	xmlFree (string);
 	return ret_val;
 }
 
 xmlNode *
-e_table_state_save_to_node      (ETableState *state,
-				 xmlNode     *parent)
+e_table_state_save_to_node (ETableState *state,
+                            xmlNode *parent)
 {
 	gint i;
 	xmlNode *node;
